#!/usr/bin/env python
#
# Copyright (c) 2016-2018, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import re
from infra_cep_helper import CEPCollecting


class CLI(CEPCollecting):
    def fill_results(self):
        out = self.execute_shell("/usr/sbin/ausearch -k vz_execs")
        args_regex = re.compile("[^:]:+[^:]+:\sargc=\d+\s(.*)")
        val_regex = re.compile("[^=\s\"]+=\"([^\"]+)\"")
        success_regex = re.compile("success=(\w+)")
        exit_regex = re.compile("exit=(\d+)")
        time_regex = re.compile("time->(.*)")
        l = list()
        v = dict()
        for line in out.splitlines():
            if line.startswith("type=EXECVE"):
                args = re.findall(args_regex, line)
                v["XmlLabel"] = "Entry"
                v["command"] = " ".join(list(re.findall(val_regex, args[0])))
            elif line.startswith("time->"):
                v["Time"] = re.findall(time_regex, line)[0]
            elif line.startswith("type=SYSCALL"):
                v["success"] = re.findall(success_regex, line)[0]
                v["exit"] = re.findall(exit_regex, line)[0]
                l.insert(0, v)
                v = dict()
        self.result["Audit"] = l


def main():
    o = CLI()
    o.run()


if __name__ == "__main__":
    main()
