#!/usr/bin/env python
#
# Copyright (c) 2016-2018, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import re
from infra_cep_helper import CEPCollecting


class CPU(CEPCollecting):
    def cpuinfo(self, name, field):
        regex = re.compile("{}\s+:\s(.*)$".format(field))
        for line in open("/proc/cpuinfo", "r"):
            s = regex.findall(line)
            if s:
                self.result[name] = s[0]

    def fill_results(self):
        self.cpuinfo("MHz", "cpu\sMHz")
        self.cpuinfo("Model", "model")
        self.cpuinfo("ModelName", "model\sname")
        self.cpuinfo("Family", "cpu\sfamily")
        self.cpuinfo("Features", "flags")

        regex = re.compile("processor\s+:\s(.*)$")
        count = 0
        for line in open("/proc/cpuinfo", "r"):
            s = regex.findall(line)
            if s:
                count = s[0]

        self.result["Cores"] = str(int(count) + 1)


def main():
    o = CPU()
    o.run()


if __name__ == "__main__":
    main()
