#!/usr/bin/env python
#
# Copyright (c) 2016-2018, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import json
import os
import re
import time
from infra_cep_helper import CEPCollecting, MAX_SCRIPT_RETRIES


class VEs(CEPCollecting):
    def fill_results(self):
        encrypted_containers = []
        cmd = "/usr/sbin/vzlist --json -a"
        out = self.execute_shell(cmd)
        ves = json.loads(out)
        for ve in ves:
            disk_path = os.path.join(ve["private"], "root.hdd/DiskDescriptor.xml")
            try:
                with open(disk_path) as f:
                    for l in f.read().splitlines():
                        # keyid means that ct is encrypted
                        m = re.findall(r"KeyId", l)
                        if m:
                           encrypted_containers.append(ve['ctid'])
            except:
                pass
        self.result["encrypted_ct"] = encrypted_containers


def main():
    o = VEs()
    o.run()


if __name__ == "__main__":
    main()
