#!/usr/bin/env python
#
# Copyright (c) 2016-2018, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import json
import time
from infra_cep_helper import CEPCollecting, MAX_SCRIPT_RETRIES


class VEs(CEPCollecting):
    def get_ct_packages(self, uuid):
        out = self.execute_shell("/usr/sbin/vzpkg list '" + uuid + "' -qp")
        ct_packages = list()
        for pkg in out.splitlines():
            ct_packages.insert(0, "-".join(pkg.split()))
        return ct_packages

    def fill_results(self):
        retries = 0
        succeed = False
        fail_reason = "Unknown reason"
        packages = dict()
        while not succeed and retries < MAX_SCRIPT_RETRIES:
            try:
                cmd = "/usr/sbin/vzlist --json"
                out = self.execute_shell(cmd)
                ctids = json.loads(out)
                for item in ctids:
                    uuid = item['ctid']
                    packages["uuid:" + uuid] = self.get_ct_packages(uuid)
                self.result["Packages"] = packages
                succeed = True
            except Exception as e:
                retries += 1
                succeed = False
                fail_reason = str(e)
                if retries >= MAX_SCRIPT_RETRIES:
                    break
                time.sleep(60 * 2 * retries)
        if not succeed:
            raise Exception("Unable to collect packages info: " + fail_reason)


def main():
    o = VEs()
    o.run()


if __name__ == "__main__":
    main()
