#!/usr/bin/env python
#
# Copyright (c) 2016-2018, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import re
import time
from infra_cep_helper import CEPCollecting, MAX_SCRIPT_RETRIES


class VZps(CEPCollecting):
    def fill_results(self):
        retries = 0
        succeed = False
        fail_reason = "Unknown reason"
        ct_dict = {}
        while not succeed and retries < MAX_SCRIPT_RETRIES:
            try:
                cmd = "/usr/bin/vzps faxh -octid,cmd"
                # skip all string's that starts from 0
                # we don't want to collect system processes
                regex = re.compile("^\s*0\s")
                out = self.execute_shell(cmd)
                for line in out.splitlines():
                    # skip all system processes
                    if regex.match(line):
                        continue
                    line = line.strip().split(" ")
                    if len(line) < 2:
                        continue
                    uuid = line[0]
                    process = "".join(line[1:])
                    if uuid not in ct_dict:
                        ct_dict[uuid] = [process]
                    else:
                        ct_dict[uuid].append(process)
                self.result["CTProcesses"] = ct_dict
                succeed = True
            except Exception as e:
                retries += 1
                succeed = False
                fail_reason = str(e)
                if retries >= MAX_SCRIPT_RETRIES:
                    break
                time.sleep(60 * 2 * retries)
        if not succeed:
            raise Exception("Unable to collect CTProcesses info: " + fail_reason)


def main():
    o = VZps()
    o.run()


if __name__ == "__main__":
    main()
