#!/usr/bin/env python
#
# Copyright (c) 2016-2021, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import json
import subprocess
import re
from infra_cep_helper import CEPCollecting, MAX_SCRIPT_RETRIES



class REPOs(CEPCollecting):
    def get_all_ct(self):
        repos_enabled = {}
        cmd = "/usr/sbin/vzlist --json"
        out = self.execute_shell(cmd)
        ctid = json.loads(out)
        for ct in ctid:
            # centos-like part
            yumlike = ['vzlinux', 'centos', 'fedora']
            if any(x in ct["distribution"] for x in yumlike):
                check_repo = subprocess.check_output(["/sbin/vzctl", "exec", ct["ctid"], "yum", "repolist", "enabled", "-q"])
                for line in check_repo.splitlines():
                    if line.startswith("repo id"):
                       continue
                    a = ' '.join(line.split()[1:])
                    if ct["ctid"] not in repos_enabled:
                       repos_enabled[ct["ctid"]] = [a]
                    else:
                       repos_enabled[ct["ctid"]].append(a)
            # end centos-like part

            # deb-like part
            deblike = ['ubuntu', 'debian']
            if any(x in ct["distribution"] for x in deblike):
                check_repo = subprocess.check_output(["/sbin/vzctl", "exec", ct["ctid"], "grep", "-r", "^[^#]", "/etc/apt/sources.list*"])
                for line in check_repo.splitlines():
                    a = ' '.join(line.split()[1:])
                    if ct["ctid"] not in repos_enabled:
                       repos_enabled[ct["ctid"]] = [a]
                    else:
                       repos_enabled[ct["ctid"]].append(a)
            # end deb-like part

            # suse-like part
            suselike = ['suse', 'sles']
            if any(x in ct["distribution"] for x in suselike):
                check_repo = subprocess.check_output(["/sbin/vzctl", "exec", ct["ctid"], "zypper", "lr", "-E", '-e', '-'])
                for line in check_repo.splitlines():
                    if line.startswith("baseurl"):
                        a = ' '.join(line.split("=")[1:])
                        if ct["ctid"] not in repos_enabled:
                            repos_enabled[ct["ctid"]] = [a]
                        else:
                            repos_enabled[ct["ctid"]].append(a)
                    else:
                        continue
            # end

        # Fallback
        return repos_enabled

    def fill_results(self):
        self.result["repos_enabled"] = self.get_all_ct()

def main():
    o = REPOs()
    o.run()


if __name__ == "__main__":
    main()
