#!/usr/bin/env python
#
# Copyright (c) 2016-2020, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import re
import time
import os
import json
import xmltodict
from infra_cep_helper import CEPCollecting


class Firewall(CEPCollecting):

    def get_fw_xml(self):
        path = '/etc/firewalld/'
        result = [os.path.join(dp, f) for dp, dn, filenames in os.walk(path) for f in filenames if os.path.splitext(f)[1] == '.xml']
        return result

    def parse_conf(self):
        conf_list = []
        conf = '/etc/firewalld/firewalld.conf'
        try:
           with open(conf) as config:
                for line in config:
                    if line.startswith('#'):
                       continue
                    else:
                       conf_list.append(line.strip())
           fwconfig = [elem for elem in conf_list if elem.strip()]
           return fwconfig
        except IOError:
           return {}
    

    def fill_results(self):
        fw_conf = {}
        xml_configs = self.get_fw_xml()
        try:
           for xml in xml_configs:
               with open(xml) as xml_conf:
                    fw_conf[xml] = xmltodict.parse(xml_conf.read())
                    xml_conf.close()
           fw_data = json.dumps(fw_conf)
           rules = json.loads(fw_data)
           self.result["firewall_rules"] = rules
        except Exception:
           pass
        self.result["firewalld.conf"] = self.parse_conf()


def main():
    o = Firewall()
    o.run()


if __name__ == "__main__":
    main()
