#!/usr/bin/env python
#
# Copyright (c) 2016-2018, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import re
import syslog
import pyudev
import json
from infra_cep_helper import CEPCollecting


class Hdd(CEPCollecting):
    def fill_results(self):
        cmd = "/usr/bin/lsblk -Ppo NAME,TYPE,SIZE,MODEL,MOUNTPOINT"
        out = self.execute_shell(cmd)
        l = list()
        processed_names = list()
        regex = re.compile("([^=\s\"]+)+=\"([^\"]+)\"")
        for line in out.splitlines():
            v = dict()
            for (name, value) in re.findall(regex, line):
                v[name.lower()] = value
            v["XmlLabel"] = "BlockDevice"
            if 'name' in v:
                processed_names.append(v['name'])
            l.insert(0, v)

        cmd = "/usr/bin/lsscsi -s"
        out = self.execute_shell(cmd)
        for line in out.splitlines():
            v = dict()
            values = line.split()
            v['name'] = values[-2]
            if v['name'] in processed_names:
                continue
            v['size'] = values[-1]
            v["XmlLabel"] = "BlockDevice"
            v['type'] = values[1]
            v['mountpoint'] = ""
            l.insert(0, v)

        real_disks = self.detect_real_disks()
        for disk in real_disks:
            self.result["SMART_info: " + disk] = self.smartctl_info(disk)

        self.result["BlockDevices"] = l

    def detect_real_disks(self):
        list = []
        context = pyudev.Context()
        for device in context.list_devices(subsystem='block', DEVTYPE='disk'):
            if device.get('MAJOR') in ["8", "259"]:
                disk = "{}".format(device.device_node)
                list.append(disk)
        return list

    def smartctl_info(self, disk):
        cmd = "/usr/sbin/smartctl --json=i -x " + (disk)
        out = self.execute_shell(cmd)
        try:
            disk_info = json.loads(out)
        except Exception as e:
            syslog.syslog("exception in {}".format(e))
            disk_info = '{}'
        return disk_info


def main():
    o = Hdd()
    o.run()


if __name__ == "__main__":
    main()
