#!/usr/bin/env python
#
# Copyright (c) 2016-2018, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

from infra_cep_helper import CEPCollecting

import re
import os

class Pfcache(CEPCollecting):
    def get_ve_root(self):
        regex = re.compile("^VE_ROOT=([^\#]*)$")
        try:
            with open("/etc/vz/vz.conf", "r") as f:
                for l in f.readlines():
                    ve_root = re.findall(regex, l.strip())
                    if ve_root:
                        return os.path.dirname(ve_root[0])
        except:
            pass
        return None


    def fill_results(self):
        l = list()
        ve_root = self.get_ve_root()
        if not ve_root:
            return

        dirs = [d for d in os.listdir(ve_root) if os.path.isdir(os.path.join(ve_root, d))]
        for d in dirs:
            out = self.execute_shell("pfcache stat " + os.path.join(ve_root, d))
            l.insert(0, {"VE_ROOT": d, "Stat": out})

        self.result["Pfcache"] = l

def main():
    o = Pfcache()
    o.run()


if __name__ == "__main__":
    main()
