#!/usr/bin/env python
#
# Copyright (c) 2016-2018, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

from infra_cep_helper import CEPCollecting
import re


class Services(CEPCollecting):

    def node_exporter_status(self):
        if self.service_active('node_exporter'):
            node_exporter_service = 'running'
        else:
            node_exporter_service = 'disabled'
        if self.port_knock('localhost', '9100'):
            node_exporter_port = '9100 open'
        else:
            node_exporter_port = '9100 closed'
        node_exporter_status = {'service': node_exporter_service, 'port': node_exporter_port}
        return node_exporter_status


    def fill_results(self):
        out = self.execute_shell("systemctl list-unit-files --no-legend")
        l = list()
        for line in out.splitlines():
            (unit, state) = line.split(None, 1)
            if self.service_active(unit):
                status = 'running'
            else:
                status = 'inactive'
            unit = re.sub(r"storage-(md|c)sd\.[^.]+\.", r"storage-\1sd.clustname.", unit)
            l.insert(0, {"Unit": unit, "State": state.strip(), "Status": status})
        self.result["node_exporter_status"] = self.node_exporter_status()
        self.result["Services"] = l


def main():
    o = Services()
    o.run()


if __name__ == "__main__":
    main()
