#!/usr/bin/env python
#
# Copyright (c) 2016-2020, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

from infra_cep_helper import CEPCollecting
from lxml import etree
import os
import re
import json
import xmltodict
import subprocess
import hashlib

class Shaman(CEPCollecting):
    def fill_results(self):
        l = {}

        if not os.path.isdir("/etc/vstorage/clusters") or not os.path.isfile("/sbin/shaman"):
            self.result['Shaman'] = l
            return

        l['Cfg'] = self.get_cfg_output()
        l['Stat'] = self.get_stats_output()
        self.result["Shaman"] = l

    def get_cfg_output(self):
        try:
            out = self.execute_shell("/sbin/shaman get-config")
            res = {}
            for l in out.splitlines():
                arr = l.split('=')
                if len(arr)==2:
                    res[arr[0].strip()] = arr[1].strip()
            return res
        except:
            return {}

    def get_stats_output(self):
        try:
            out = self.execute_shell("/sbin/shaman stat -X")
            return xmltodict.parse(out)
        except:
            return {}



def main():
    o = Shaman()
    o.run()

if __name__ == "__main__":
    main()
