#!/usr/bin/env python
#
# Copyright (c) 2016-2018, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import re
import time
from infra_cep_helper import CEPCollecting, MAX_SCRIPT_RETRIES


class Simfs(CEPCollecting):
    def fill_results(self):
        retries = 0
        succeed = False
        fail_reason = "Unknown reason"
        while not succeed and retries < MAX_SCRIPT_RETRIES:
            try:
                cts = list()
                cmd = ("/usr/sbin/vzlist -aH -o"
                       " layout,ctid,diskspace,diskspace.s,diskspace.h")
                out = self.execute_shell(cmd)
                for line in out.splitlines():
                    v = dict()
                    (v["layout"], v["ctid"], v["diskspace"],
                     v["diskspace.s"], v["diskspace.h"]) = line.split()
                    if v["layout"] == "4":
                        v["XmlLabel"] = "CT"
                        cts.insert(0, v)
                self.result["IsUsed"] = 0
                if len(cts):
                    self.result["CTs"] = cts
                    self.result["IsUsed"] = 1
                else:
                    regex = re.compile("^VEFSTYPE=([^\#]*)$")
                    with open("/etc/vz/vz.conf", "r") as f:
                        for l in f.readlines():
                            try:
                                value = re.findall(regex, l.strip())[0]
                                if value.strip('"') == "simfs":
                                    self.result["IsUsed"] = 1
                            except:
                                continue
                            break
                succeed = True
            except Exception as e:
                retries += 1
                succeed = False
                fail_reason = str(e)
                if retries >= MAX_SCRIPT_RETRIES:
                    break
                time.sleep(60 * 2 * retries)
        if not succeed:
            raise Exception("Unable to collect simfs info: " + fail_reason)


def main():
    o = Simfs()
    o.run()


if __name__ == "__main__":
    main()
