#!/usr/bin/env python
#
# Copyright (c) 2016-2018, Virtuozzo International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import json
import os
import re
import time
import subprocess
from infra_cep_helper import CEPCollecting, MAX_SCRIPT_RETRIES

class VEs(CEPCollecting):
    def fill_results(self):
        retries = 0
        succeed = False
        fail_reason = "Unknown reason"
        r = re.compile("^([^=\#]+)=([^\#]*)$")
        use_vzctl = False
        if os.path.isfile("/usr/bin/prlctl"):
            cmd = "/usr/bin/prlctl list -ai --full --json"
        elif os.path.isfile("/usr/sbin/vzlist"):
            cmd = "/usr/sbin/vzlist -a --json"
            use_vzctl = True
        else:
            return
        while not succeed and retries < MAX_SCRIPT_RETRIES:
            try:
                out = self.execute_shell(cmd)
                ves = json.loads(out)
                for ve in ves:
                    if use_vzctl:
                        l = list()
                        home_path = os.path.join(ve["private"], "ve.conf")
                        ct_id =  ve["ctid"]
                        try:
                            check_stamp = subprocess.check_output(["/sbin/vzctl", "exec", ct_id, "test", "-f", "/var/log/vzconvert8.stamp"])
                            flag_status = "enabled"
                        except Exception:
                            flag_status = "disabled"
                        l.insert(0, {"vzconvert8": flag_status})
                        try:
                            check_stamp = subprocess.check_output(["/sbin/vzctl", "exec", ct_id, "test", "-f", "/var/log/vzconvert7.stamp"])
                            flag_status = "enabled"
                        except Exception:
                            flag_status = "disabled"
                        l.insert(0, {"vzconvert7": flag_status})
                        with open(home_path, "r") as f:
                            for line in f.readlines():
                                try:
                                    (name, value) = re.findall(r, line.strip())[0]
                                    l.insert(0, {name: value.strip("\"")})
                                except:
                                    continue
                        ve["CtConfig"] = l
                    elif "Type" in ve and ve["Type"] == "CT":
                        l = list()
                        home_path = os.path.join(ve["Home"], "ve.conf")
                        ct_id =  ve["ID"]
                        try:
                            check_stamp = subprocess.check_output(["/sbin/vzctl", "exec", ct_id, "test", "-f", "/var/log/vzconvert8.stamp"])
                            flag_status = "enabled"
                        except Exception:
                            flag_status = "disabled"
                        l.insert(0, {"vzconvert8": flag_status})
                        try:
                            check_stamp = subprocess.check_output(["/sbin/vzctl", "exec", ct_id, "test", "-f", "/var/log/vzconvert7.stamp"])
                            flag_status = "enabled"
                        except Exception:
                            flag_status = "disabled"
                        l.insert(0, {"vzconvert7": flag_status})
                        with open(home_path, "r") as f:
                            for line in f.readlines():
                                try:
                                    (name, value) = re.findall(r, line.strip())[0]
                                    l.insert(0, {name: value.strip("\"")})
                                except:
                                    continue
                        ve["CtConfig"] = l

                    self.prepare_tags(ve)
                    ve["XmlLabel"] = "VE"

                self.result["VEs"] = ves
                succeed = True
            except Exception as e:
                retries += 1
                succeed = False
                fail_reason = str(e)
                if retries >= MAX_SCRIPT_RETRIES:
                    break
                time.sleep(60 * 2 * retries)
        if not succeed:
            raise Exception("Unable to collect ves info: " + fail_reason)


def main():
    o = VEs()
    o.run()


if __name__ == "__main__":
    main()
